import {NgModule} from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';

import {AppRoutingModule} from './app-routing.module';
import {AppComponent} from './components/app.component';
import {SigningComponent} from './components/signing/signing.component';
import {BASE_PATH} from '../gen';
import {environment} from '../environments/environment';
import {HTTP_INTERCEPTORS, provideHttpClient, withInterceptorsFromDi} from '@angular/common/http';
import { LoginComponent } from './components/login/login.component';
import {FormsModule} from '@angular/forms';
import {RequestInterceptor} from './interceptors/request.interceptor';
import {UnauthorizedInterceptor} from './interceptors/unauthorizedResponseInterceptor';
import {SigningSidebarComponent} from './components/signing/signing-sidebar/signing-sidebar.component';
import {
  SigningSidebarItemComponent
} from './components/signing/signing-sidebar/signing-sidebar-item/signing-sidebar-item.component';

@NgModule({
  declarations: [
    AppComponent,
    SigningComponent,
    LoginComponent,
    SigningSidebarComponent
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    FormsModule,
    SigningSidebarItemComponent
  ],
  providers: [
    {provide: BASE_PATH, useValue: environment.apiBasePath},
    {provide: HTTP_INTERCEPTORS, useClass: UnauthorizedInterceptor, multi: true},
    {provide: HTTP_INTERCEPTORS, useClass: RequestInterceptor, multi: true},
    provideHttpClient(withInterceptorsFromDi())
  ],
  bootstrap: [AppComponent]
})
export class AppModule {
}
