import {Component, OnInit} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {
  GetSigningRequestResponse,
  GetSigningRequestResponseSigningRequestDocument, PatchOperation, SigningRequestDocumentService,
  SigningRequestService
} from '../../../gen';

@Component({
  selector: 'app-hello',
  standalone: false,
  templateUrl: './signing.component.html',
  styleUrl: './signing.component.css'
})
export class SigningComponent implements OnInit {
  documents: GetSigningRequestResponseSigningRequestDocument[] = [];
  selectedDocument: GetSigningRequestResponseSigningRequestDocument = {
    confirmed: false, id: '', name: ''
  }

  constructor(private route: ActivatedRoute, private signingRequestService: SigningRequestService, private signingRequestDocumentService: SigningRequestDocumentService) {
  }

  ngOnInit(): void {
    const id: string = this.route.snapshot.paramMap.get("id") || "";

    this.signingRequestService.getSigningRequest(id).subscribe({
      next: (response: GetSigningRequestResponse): void => {
        this.documents = response.signingRequestDocuments || [];
      },
      error(err: Error): void {
        console.log(err);
      }
    });
  }

  setActiveDocument(document: GetSigningRequestResponseSigningRequestDocument): void {
    this.selectedDocument = document;
    console.log(this.selectedDocument);
  }

  onConfirm(): void {
    this.patchDocument(this.selectedDocument);
  }

  patchDocument(signingRequestDocument: GetSigningRequestResponseSigningRequestDocument): void {
    const patch: PatchOperation = {
      op: "replace", path: "/confirmed", value: "true"
    }
    this.signingRequestDocumentService.patchSigningRequestDocument(this.selectedDocument.id, Array.of(patch));
    this.selectedDocument.confirmed = true;
  }
}
